SystemOrganization addCategory: #ConfigurationOfOmni!

Object subclass: #ConfigurationOfOmni
	instanceVariableNames: 'project STorVM IsolateOrNoOpt'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfOmni'!

!ConfigurationOfOmni class methodsFor: 'development support' stamp: 'StefanMarr 11/9/2011 00:54'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfOmni class methodsFor: 'private' stamp: 'StefanMarr 11/9/2011 00:54'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfOmni class methodsFor: 'private' stamp: 'StefanMarr 11/9/2011 00:54'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfOmni class methodsFor: 'private' stamp: 'StefanMarr 11/9/2011 00:54'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfOmni class methodsFor: 'metacello tool support' stamp: 'StefanMarr 11/9/2011 00:54'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfOmni class methodsFor: 'loading' stamp: 'StefanMarr 11/9/2011 00:54'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfOmni class methodsFor: 'loading' stamp: 'StefanMarr 11/9/2011 00:54'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfOmni class methodsFor: 'loading' stamp: 'StefanMarr 11/9/2011 00:54'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfOmni class methodsFor: 'loading' stamp: 'StefanMarr 6/12/2013 00:14'!
loadLocal: aConfiguration
	"Load the latest versions of the mcz files defined for this project."

	" self loadLocal: #(ST Isolate).
	  self loadLocal: #(ST NoOpt).
	  self loadLocal: #(VM Isolate).
	  self loadLocal: #(VM NoOpt).
	"

	<apiDocumentation>
	| version result |
	version := (self project: aConfiguration) version: #bleedingEdge.
	version repositoryOverrides: { MCDirectoryRepository new directory: (FileDirectory on: '/Users/smarr/Projects/monticello.repo') }.

	self preLoadScript.
	result := version load.
	self postLoadScript: aConfiguration.
	^ result! !

!ConfigurationOfOmni class methodsFor: 'loading' stamp: 'StefanMarr 1/16/2013 13:41'!
loadPhD2013
	"This configuration reflects the project status used for benchmarks in my PhD dissertation"

	"self loadPhD2013"

	<apiDocumentation>
	^(self project version: #'phd2013') load! !

!ConfigurationOfOmni class methodsFor: 'loading' stamp: 'StefanMarr 1/15/2012 21:56'!
loadTOOLS2012
	"This configuration represents the state of the project used for the initial paper submission
	 for TOOLS 2012"

	"self loadTOOLS2012"

	<apiDocumentation>
	^(self project version: #'tools2012') load! !

!ConfigurationOfOmni class methodsFor: 'scripts' stamp: 'StefanMarr 6/18/2013 00:03'!
postLoadScript: aConfiguration
	
	(Smalltalk globals at: #RVMOperations)    initializeProcessClass.
	(Smalltalk globals at: #LRSTMTransaction) initializeLRSTM.
	
	(aConfiguration includes: #ST) ifTrue: [
		(Smalltalk globals at: #OstTransformer)
			initializeForTarget: (aConfiguration intersection: #(Isolate NoOpt)) first;
          initializeOST.
 		(Smalltalk globals at: #OstCompiler) initializeOST.
		(Smalltalk globals at: #OstDomain)   initializeOST.
		(Smalltalk globals at: #OstCompiler) recompileSystemWithOstCompiler].
	
	(aConfiguration includes: #VM) ifTrue: [
		(Smalltalk globals at: #ONOMirror) initializeOST].
	
	Process class removeSelector: #shouldNotBeRedefined.! !

!ConfigurationOfOmni class methodsFor: 'scripts' stamp: 'StefanMarr 6/11/2013 16:52'!
preLoadScript
	"Disable warning"
	self assert: (Process class includesLocalSelector: #shouldNotBeRedefined) not.
	
	Process class compileSilently: 'shouldNotBeRedefined ^ false' classified: '' notifying: nil.! !

!ConfigurationOfOmni class methodsFor: 'accessing' stamp: 'StefanMarr 6/11/2013 23:52'!
project: aConfiguration
	
	^ self new configuration: aConfiguration;
		project! !

!ConfigurationOfOmni class methodsFor: 'transporter' stamp: 'StefanMarr 12/11/2011 19:18'!
subPackages
	"Specifies the names of all logical subpackages of the Omni package."
	"TODO: have a versioning for this, to better comply with the Metacello approach."
	^ {	'OmniST-Core'.
		'OmniST-Languages'.
		'OmniVM'.
	}! !

!ConfigurationOfOmni class methodsFor: 'development support' stamp: 'StefanMarr 11/9/2011 00:54'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfOmni methodsFor: 'baselines' stamp: 'StefanMarr 5/16/2013 15:52'!
baseline01: spec
	<version: '0.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		
		"AST-Compiler (RBCompiler)"
		spec package: 'AST-Compiler' with: [
				spec repository: 'http://source.lukas-renggli.ch/helvetia'].
		
		"SMark Benchmarking"
		spec project: 'Benchmarking'
			with:
				[ spec
					className: 'ConfigurationOfBenchmarking';
					file: 'ConfigurationOfBenchmarking';
					repository: 'http://smalltalkhub.com/mc/StefanMarr/SMark/main' ].
		
		spec
			repository: 'http://ss3.gemstone.com/ss/Omni';
			package: 'OmniPrerequisites';

			package: 'OmniST-Core' with: [
				spec 
					requires:   #('AST-Compiler' 'Benchmarking' 'OmniPrerequisites').];
			
			package: 'ClojureST';
			
			package: 'OmniST-Languages' with: [
				spec requires: #('OmniST-Core' 'ClojureST')];
			
			package: 'OmniST-Benchmarks' with: [
				spec requires: #('OmniST-Core' 'OmniST-Languages')];
			
			package: 'OmniST-Tests-Core' with: [
				spec requires: #('OmniST-Core')];
			
			package: 'OmniST-Tests-Languages' with: [
				spec requires: #('OmniST-Languages')];
			
			package: 'AmbientTalkST-Benchmarks' with: [
				spec requires: #('OmniST-Languages' 'OmniST-Benchmarks')]

			"package: 'OmniVM'"
	].
! !

!ConfigurationOfOmni methodsFor: 'baselines' stamp: 'StefanMarr 5/16/2013 15:53'!
baseline03: spec
	<version: '0.3-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		
		"RooarVM compatibility package"
		spec package: 'RoarVM' with: [
				spec repository: 'http://ss3.gemstone.com/ss/RoarVM'].
		
		"AST Basis"
		spec package: 'AST-Core' with: [
				spec repository: 'http://www.squeaksource.com/rb'].
		spec package: 'AST-Semantic' with: [
				spec
					repository: 'http://www.squeaksource.com/rb';
					requires: #('AST-Core')].
		
		"AST-Compiler (RBCompiler)"
		spec package: 'AST-Compiler' with: [
				spec repository: 'http://source.lukas-renggli.ch/helvetia'].
		
		"SMark Benchmarking"
		spec project: 'Benchmarking'
			with:
				[ spec
					className: 'ConfigurationOfBenchmarking';
					versionString: '0.2';
					repository: 'http://smalltalkhub.com/mc/StefanMarr/SMark/main' ].
		
		spec
			repository: 'http://ss3.gemstone.com/ss/Omni';
			package: 'OmniPrerequisites';

			package: 'OmniST-Core' with: [
				spec 
					requires:   #('AST-Compiler' Benchmarking OmniPrerequisites RoarVM).];
			
			package: 'ClojureST';
			
			package: 'OmniST-Languages' with: [
				spec requires: #('OmniST-Core' 'ClojureST')];
			
			package: 'CLBG-Compatibility' with: [ "Factory classes"
				spec requires: #('Benchmarking')];
			package: 'OmniST-CLBG-Compatibility' with: [ "Omni Object classes"
				spec requires: #('Benchmarking' 'CLBG-Compatibility')];
			 
			package: 'OmniST-Benchmarks' with: [
				spec requires: #('OmniST-Core' 'OmniST-Languages' 'OmniST-CLBG-Compatibility')];
			
			package: 'OmniST-Tests-Core' with: [
				spec requires: #('OmniST-Core')];
			
			package: 'OmniST-Tests-Languages' with: [
				spec requires: #('OmniST-Languages')];
			
			package: 'AmbientTalkST-Benchmarks' with: [
				spec requires: #('OmniST-Languages' 'OmniST-Benchmarks')].
		
		"LRSTM packages"
		spec package: 'LRSTM-Benchmarks' with: [
			spec repository: 'http://ss3.gemstone.com/ss/LRSTM'].
		spec package: 'LRSTM-Tests' with: [
			spec repository: 'http://ss3.gemstone.com/ss/LRSTM'].
	].
! !

!ConfigurationOfOmni methodsFor: 'baselines' stamp: 'StefanMarr 7/3/2013 15:54'!
baseline04: spec
	<version: '0.4-baseline'>

	spec for: #'common' do: [
		| platformCore |
		spec blessing: #'baseline'.
		
		"RoarVM compatibility package"
		spec package: 'RoarVM' with: [ spec repository: 'http://ss3.gemstone.com/ss/RoarVM'].
		
		"SMark Benchmarking"
		spec project: 'Benchmarking' with: [
				spec className: 'ConfigurationOfBenchmarking';
					  file: 'ConfigurationOfBenchmarking';
					  version: #bleedingEdge;
					  repository: 'http://smalltalkhub.com/mc/StefanMarr/SMark/main' ].
		
		"AST Basis and AST-Compiler (RBCompiler)"
		STorVM = #ST ifTrue: [
			spec package: 'AST-Core'     with: [ spec repository: 'http://www.squeaksource.com/rb'].
			spec package: 'AST-Semantic' with: [
					spec repository: 'http://www.squeaksource.com/rb';
						  requires: #('AST-Core')].
			spec package: 'AST-Compiler' with: [ spec repository: 'http://source.lukas-renggli.ch/helvetia']].

		spec
			repository: 'http://ss3.gemstone.com/ss/Omni';
			package: 'ClojureST';

			package: 'O-Base-Compat';
			package: 'O-Base-Overrides'.
		
		STorVM = #ST ifTrue: [ 
			spec package: 'O-Core-Misc' with: 'O-Core-Misc.WithOwner-StefanMarr.5';
			     package: 'O-STPrerequisites' ].
		STorVM = #VM ifTrue: [ spec package: 'O-Core-Misc' with: 'O-Core-Misc.NoOwner-StefanMarr.6'].
		
		
		spec
			package: 'O-Core-Reflection';
			package: 'O-Benchmarks' with: [ spec requires: #('Benchmarking')];
			
			package: 'O-CLBG-Compatibility' with: [ "Omni Object classes"
				
				STorVM = #ST ifTrue: [ spec file: 'O-CLBG-Compatibility.WithOwner-StefanMarr.7' ].
				STorVM = #VM ifTrue: [ spec file: 'O-CLBG-Compatibility.NoOwner-StefanMarr.8'   ].
				
				spec requires: #('Benchmarking' 'O-Core-Misc')].
		
		STorVM = #ST ifTrue: [
			platformCore := 'O-ST-Core'.
			spec package: 'O-ST-Core' with: [
					spec requires: #('AmbientTalkST-Benchmarks' 'LRSTM-Benchmarks'
					                 'O-Core-Misc' 'O-CLBG-Compatibility'
					                 'AST-Core' 'AST-Semantic' 'AST-Compiler')]].
		STorVM = #VM ifTrue: [
			platformCore := 'O-VM-Core'.
			spec package: 'O-VM-Core' with: [
					spec requires: #('AmbientTalkST-Benchmarks' 'LRSTM-Benchmarks'
					                 'O-Core-Misc' 'O-CLBG-Compatibility') ]].
		
		spec package: 'O-Languages' with: [
				spec requires: {'LRSTM-Model'. platformCore. 'O-Core-Misc'}].
		
		IsolateOrNoOpt = #Isolate ifTrue: [
			spec package: 'O-Isolate' with: [ spec requires: {'O-Languages'. platformCore. 'O-Tests'} ].
			STorVM = #ST ifTrue: [ spec package: 'O-ST-Isolate' with: [ spec requires: #('O-ST-Core' 'O-Isolate') ]].
			STorVM = #VM ifTrue: [ spec package: 'O-VM-Isolate' with: [ spec requires: #('O-VM-Core' 'O-Isolate') ]]].
		
		IsolateOrNoOpt = #NoOpt ifTrue: [
			spec package: 'O-NoOpt' with: [ spec requires: {'O-Languages'. platformCore. 'O-Tests'} ].
			STorVM = #ST ifTrue: [ spec package: 'O-ST-NoOpt' with: [ spec requires: #('O-ST-Core' 'O-NoOpt') ]].
			STorVM = #VM ifTrue: [ spec package: 'O-VM-NoOpt' with: [ spec requires: #('O-VM-Core' 'O-NoOpt') ]]].

		spec package: 'O-Tests' with: [ spec requires: #('ClojureST' 'O-Core-Misc' 'O-Languages')].
		
		STorVM = #ST ifTrue: [ spec package: 'O-ST-Tests' with: [ spec requires: #('O-Core-Misc')]].
		STorVM = #VM ifTrue: [ spec package: 'O-VM-Tests' with: [ spec requires: #('O-Core-Misc' 'O-Tests')]].

		"AmbientTalkST"
		spec package: 'AmbientTalkST-Tests' with: [
				spec requires: #('O-Core-Misc' 'O-Languages')];
		     package: 'AmbientTalkST-Ost-Tests' with: [
				spec requires: #('O-Core-Misc')];
		     package: 'AmbientTalkST-Benchmarks' with: [
				spec requires: #('O-CLBG-Compatibility' 'Benchmarking')].
		
		"LRSTM packages"
		spec package: 'LRSTM-Model' with: [
			spec repository: 'http://ss3.gemstone.com/ss/LRSTM'].
		spec package: 'LRSTM-Benchmarks' with: [
			spec repository: 'http://ss3.gemstone.com/ss/LRSTM'.
			spec requires: #('LRSTM-Model')].
		spec package: 'LRSTM-Tests' with: [
			spec repository: 'http://ss3.gemstone.com/ss/LRSTM'.
			spec requires: #('LRSTM-Model')].
	].! !

!ConfigurationOfOmni methodsFor: 'accessing' stamp: 'StefanMarr 7/1/2013 16:36'!
configuration: anArrayOfSymbols
	" self configuration: #(VM Isolate).
	  self configuration: #(ST NoOpt)... "
	
	"These options are exclusive each:"
	self assert: (anArrayOfSymbols includesAll: #(VM ST)) not.
	self assert: (anArrayOfSymbols includesAll: #(Isolate NoOpt)) not.
	
	STorVM         := (anArrayOfSymbols intersection: #(VM ST)) first.
	IsolateOrNoOpt := (anArrayOfSymbols intersection: #(Isolate NoOpt)) first.! !

!ConfigurationOfOmni methodsFor: 'symbolic versions' stamp: 'StefanMarr 1/16/2013 13:52'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '0.4-baseline'.
! !

!ConfigurationOfOmni methodsFor: 'symbolic versions' stamp: 'StefanMarr 1/16/2013 13:42'!
phd2013: spec
	<symbolicVersion: #'phd2013'>

	spec for: #'common' version: '0.3-phd2013'! !

!ConfigurationOfOmni methodsFor: 'accessing' stamp: 'StefanMarr 11/9/2011 00:54'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfOmni methodsFor: 'symbolic versions' stamp: 'StefanMarr 1/15/2012 21:55'!
tools2012: spec
	<symbolicVersion: #'tools2012'>

	spec for: #'common' version: '0.2-tools2012'.
! !

!ConfigurationOfOmni methodsFor: 'versions' stamp: 'StefanMarr 11/9/2011 00:54'!
version01: spec
	<version: '0.1' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'StefanMarr'.
		spec timestamp: '5/14/2011 12:19'.
	].! !

!ConfigurationOfOmni methodsFor: 'versions' stamp: 'StefanMarr 1/15/2012 22:29'!
version02: spec
	<version: '0.2-tools2012' imports: #('0.1-baseline') >

	spec for: #'common' do: [
		spec blessing: #'tools2012'.
		spec description: 'Configuration reflecting the project status used for the initial TOOLS2012 submission'.
		spec author: 'StefanMarr'.
		spec timestamp: '1/15/2012 21:25'.
	
		spec
			package: 'AST-Compiler' 		with: 'AST-Compiler-lr.37';
			package: 'OmniPrerequisites' 	with: 'OmniPrerequisites-StefanMarr.1';
			package: 'OmniST-Core' 			with: 'OmniST-Core-StefanMarr.27';
			package: 'ClojureST'			with: 'ClojureST-StefanMarr.3';
			package: 'OmniST-Languages'	with: 'OmniST-Languages-StefanMarr.19';
			package: 'OmniST-Benchmarks'	with: 'OmniST-Benchmarks-StefanMarr.5';
			package: 'OmniST-Tests-Core'	with: 'OmniST-Tests-Core-StefanMarr.2';
			package: 'OmniST-Tests-Languages' with: 'OmniST-Tests-Languages-StefanMarr.6';
			package: 'AmbientTalkST-Benchmarks' with: 'AmbientTalkST-Benchmarks-StefanMarr.16'
	].! !

!ConfigurationOfOmni methodsFor: 'versions' stamp: 'StefanMarr 1/16/2013 13:52'!
version03: spec
	<version: '0.3-phd2013' imports: #('0.3-baseline') >

	spec for: #'common' do: [
		spec blessing: #'phd2013'.
		spec description: 'Configuration reflecting the project status used for benchmarks in my PhD dissertation'.
		spec author: 'StefanMarr'.
		spec timestamp: '1/16/2013 13:43'.
	
		spec
			package: 'RoarVM' 						with: 'RoarVM-StefanMarr.10';
			package: 'AST-Compiler' 				with: 'AST-Compiler-lr.37';
			package: 'OmniPrerequisites' 			with: 'OmniPrerequisites-StefanMarr.1';
			package: 'OmniST-Core' 					with: 'OmniST-Core-StefanMarr.49';
			package: 'ClojureST'					with: 'ClojureST-StefanMarr.3';
			package: 'OmniST-Languages'			with: 'OmniST-Languages-StefanMarr.43';
			package: 'CLBG-Compatibility'			with: 'CLBG-Compatibility-StefanMarr.1';
			package: 'OmniST-CLBG-Compatibility'	with: 'OmniST-CLBG-Compatibility-StefanMarr.4';
			package: 'OmniST-Benchmarks'			with: 'OmniST-Benchmarks-StefanMarr.20';
			package: 'OmniST-Tests-Core'			with: 'OmniST-Tests-Core-StefanMarr.28';
			package: 'OmniST-Tests-Languages' 	with: 'OmniST-Tests-Languages-StefanMarr.27';
			package: 'AmbientTalkST-Benchmarks'	with: 'AmbientTalkST-Benchmarks-StefanMarr.27';
			package: 'LRSTM-Benchmarks'			with: 'LRSTM-Benchmarks-StefanMarr.1';
			package: 'LRSTM-Tests'					with: 'LRSTM-Tests-StefanMarr.1'
	].! !
